@@ -2,7 +2,7 @@ import pytest
 
 from aioresponses import aioresponses
 
-from ujenkins import JenkinsClient
+from ujenkins import AsyncJenkinsClient, JenkinsClient
 
 
 @pytest.fixture
@@ -18,3 +18,12 @@ def client():
     j.crumb = False
     yield j
     j.close()
+
+
+@pytest.fixture
+async def async_client():
+    j = AsyncJenkinsClient('http://server')
+    # disable crumb wrapper for simplify testing
+    j.crumb = False
+    yield j
+    await j.close()
