@@ -1,8 +1,8 @@
 from ujenkins.adapters.aio import AsyncJenkinsClient
 from ujenkins.adapters.sync import JenkinsClient
-from ujenkins.exceptions import JenkinsError
+from ujenkins.exceptions import JenkinsError, JenkinsNotFoundError
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 __all__ = (
     # adapters
@@ -10,4 +10,5 @@ __all__ = (
     'JenkinsClient',
     # exceptions
     'JenkinsError',
+    'JenkinsNotFoundError',
 )
